@@ -505,6 +505,7 @@ class ExecuteRemoteBatch():
 
    def buildSerialFile(self):
       rawSubmissionScript = self.submissionScriptsInfo.getSubmissionScript('Batch',self.clusterBatchSystem,'pegasusserial')
+      rawSubmissionScriptMessage = "SubmissionScripts/Distributor/Batch/%s/pegasusserial" % (self.clusterBatchSystem)
 
       queueCommand = ""
       if self.clusterQueue != "":
@@ -578,7 +579,8 @@ class ExecuteRemoteBatch():
          submissionScript = template.substitute_recur(substitutions)
       except KeyError as e:
          submissionScript = ""
-         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@%s\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("Pattern substitution failed for @@{%s}\n" % (e.args[0])))
+         self.logger.log(logging.ERROR,getLogMessage("in %s\n" % (rawSubmissionScriptMessage)))
       except TypeError:
          submissionScript = ""
          self.logger.log(logging.ERROR,getLogMessage("Submission script substitution failed:\n%s\n" % (rawSubmissionScript)))
