@@ -98,6 +98,9 @@ class VenueMechanismSsh(VenueMechanismCore):
                 nCpus,
                 nNodes,
                 ppn,
+                nGpus,
+                gpn,
+                memoryMB,
                 wallTime,
                 x509SubmitProxy,
                 disableProbeCheck,
@@ -110,7 +113,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                        timeHistoryLogs,disableJobMonitoring,
                                        siteInfo,tapis2SiteInfo,tapis3SiteInfo,fileMoverInfo,
                                        toolFilesInfo,dockerImageInfo,submissionScriptsInfo,managerInfo,
-                                       remoteMonitors,isMultiCoreRequest,nCpus,nNodes,ppn,event)
+                                       remoteMonitors,isMultiCoreRequest,nCpus,nNodes,ppn,nGpus,gpn,memoryMB,event)
 
       self.logger                           = logging.getLogger(__name__)
       self.jobOutput                        = JobOutput()
@@ -294,7 +297,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                               self.executable,self.arguments,self.stdinput,
                                               self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                               self.submissionScriptsInfo,
-                                              self.managerInfo,self.nNodes,self.ppn,self.wallTime,
+                                              self.managerInfo,self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,self.wallTime,
                                               self.quotaLimit,
                                               self.timeHistoryLogs)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
@@ -319,7 +322,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                               self.executable,self.arguments,self.stdinput,
                                               self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                               self.submissionScriptsInfo,
-                                              self.managerInfo,self.nNodes,self.ppn,self.wallTime,
+                                              self.managerInfo,self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,self.wallTime,
                                               self.quotaLimit,
                                               self.timeHistoryLogs)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
@@ -344,7 +347,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                               self.executable,self.arguments,self.stdinput,
                                               self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                               self.submissionScriptsInfo,
-                                              self.managerInfo,self.nNodes,self.ppn,
+                                              self.managerInfo,self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,
                                               self.wallTime,self.quotaLimit,
                                               self.timeHistoryLogs)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
@@ -369,7 +372,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                              self.executable,self.arguments,self.stdinput,
                                              self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                              self.submissionScriptsInfo,
-                                             self.managerInfo,self.nNodes,self.ppn,
+                                             self.managerInfo,self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,
                                              self.wallTime,self.quotaLimit,
                                              self.timeHistoryLogs)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
@@ -394,7 +397,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                 self.executable,self.arguments,self.stdinput,
                                                 self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                                 self.submissionScriptsInfo,
-                                                self.managerInfo,self.nNodes,self.ppn,
+                                                self.managerInfo,self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,
                                                 self.wallTime,self.quotaLimit,
                                                 self.timeHistoryLogs)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
@@ -418,7 +421,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                  appScriptName,self.environment,
                                                  self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                                  self.submissionScriptsInfo,
-                                                 self.managerInfo,self.wallTime)
+                                                 self.managerInfo,self.nGpus,self.gpn,self.memoryMB,self.wallTime)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
             batchLogName                                      = self.remoteBatch.getBatchLog()
             nodeFileName,nodeList                             = self.remoteBatch.getBatchNodeList()
@@ -504,7 +507,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                   appScriptName,self.environment,
                                                   self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                                   self.submissionScriptsInfo,
-                                                  self.managerInfo,self.x509SubmitProxy,self.wallTime)
+                                                  self.managerInfo,self.x509SubmitProxy,
+                                                  self.nGpus,self.gpn,self.memoryMB,self.wallTime)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
             batchLogName                                      = self.remoteBatch.getBatchLog()
             nodeFileName,nodeList                             = self.remoteBatch.getBatchNodeList()
@@ -541,7 +545,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                            self.instanceDirectory,remoteScratchDirectory,
                                                            self.useSetup,self.pegasusVersion,self.pegasusHome,
                                                            self.pegasusTemplates,self.x509SubmitProxy,self.sshIdentityPath,
-                                                           self.gridsite,self.pegasusSiteInfo,self.wallTime,
+                                                           self.gridsite,self.pegasusSiteInfo,
+                                                           self.nGpus,self.gpn,self.memoryMB,self.wallTime,
                                                            self.siteInfo,self.submissionScriptsInfo,
                                                            self.managerInfo,self.timeHistoryLogs)
                   batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.buildWorkflowScript()
@@ -573,7 +578,8 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                      self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                                      self.submissionScriptsInfo,self.managerInfo,
                                                      self.x509SubmitProxy,self.sshIdentityPath,self.gridsite,self.pegasusSiteInfo,
-                                                     self.wallTime,self.timeHistoryLogs)
+                                                     self.nGpus,self.gpn,self.memoryMB,self.wallTime,
+                                                     self.timeHistoryLogs)
                batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
                batchLogName                                      = self.remoteBatch.getBatchLog()
                nodeFileName,nodeList                             = self.remoteBatch.getBatchNodeList()
@@ -603,7 +609,7 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.remoteBatch = RemoteBatchTAPIS2(self.session,self.instanceToken,self.wsJobId,
                                                  self.runName,self.localJobId,self.instanceId,
                                                  self.tapis2SiteInfo,self.submissionScriptsInfo,
-                                                 self.nNodes,self.ppn,self.wallTime)
+                                                 self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,self.wallTime)
             batchScriptName,batchScript = self.remoteBatch.getBatchTapisFile()
             batchScriptExecutable       = False
             batchLogName                = ""
@@ -620,7 +626,7 @@ class VenueMechanismSsh(VenueMechanismCore):
             self.remoteBatch = RemoteBatchTAPIS3(self.session,self.instanceToken,self.wsJobId,
                                                  self.runName,self.localJobId,self.instanceId,
                                                  self.tapis3SiteInfo,self.submissionScriptsInfo,
-                                                 self.nNodes,self.ppn,self.wallTime)
+                                                 self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,self.wallTime)
             batchScriptName,batchScript = self.remoteBatch.getBatchTapisFile()
             batchScriptExecutable       = False
             batchLogName                = ""
@@ -646,7 +652,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                    self.runName,self.localJobId,self.instanceId,self.workingDirectory,appScriptName,
                                                    self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                                    self.submissionScriptsInfo,
-                                                   self.managerInfo,self.nNodes,self.ppn,
+                                                   self.managerInfo,self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,
                                                    self.timeHistoryLogs)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
             batchLogName                                      = self.remoteBatch.getBatchLog()
@@ -668,7 +674,7 @@ class VenueMechanismSsh(VenueMechanismCore):
                                                    self.runName,self.localJobId,self.instanceId,self.workingDirectory,appScriptName,
                                                    self.isMultiCoreRequest,self.siteInfo,self.toolFilesInfo,self.dockerImageInfo,
                                                    self.submissionScriptsInfo,
-                                                   self.managerInfo,self.nNodes,self.ppn,
+                                                   self.managerInfo,self.nNodes,self.ppn,self.nGpus,self.gpn,self.memoryMB,
                                                    self.timeHistoryLogs)
             batchScriptName,batchScript,batchScriptExecutable = self.remoteBatch.getBatchScript()
             batchLogName                                      = self.remoteBatch.getBatchLog()
